@@ -24,12 +24,15 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 
+#include <libexif/exif-data.h>
+
+#include "file.h"
 #include "wallpaper_manager.h"
 
 gint 
 rstto_wallpaper_manager_configure_dialog_run (
         RsttoWallpaperManager *self,
-        GFile *file)
+        RsttoFile *file)
 {
     return RSTTO_WALLPAPER_MANAGER_GET_IFACE (self)->configure_dialog_run(self, file);
 }
@@ -43,7 +46,7 @@ rstto_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 gboolean
 rstto_wallpaper_manager_set (
         RsttoWallpaperManager *self,
-        GFile *file)
+        RsttoFile *file)
 {
     return RSTTO_WALLPAPER_MANAGER_GET_IFACE (self)->set (self, file);
 }
@@ -52,7 +55,6 @@ rstto_wallpaper_manager_set (
 static void
 rstto_wallpaper_manager_iface_init (gpointer g_iface)
 {
-    RsttoWallpaperManagerIface *iface = (RsttoWallpaperManagerIface *)g_iface;
 }
 
 
